# Disable automatic .la file removal
%global __brp_remove_la_files %nil

Name:		neon
Version:	0.33.0
Release: 	1
Summary:	An HTTP and WebDAV client library
License:	LGPL-2.0-or-later
URL:            https://notroj.github.io/neon/
Source0:        https://notroj.github.io/neon/%{name}-%{version}.tar.gz
Patch0:         neon-0.32.2-multilib.patch

BuildRequires:  gcc openssl-devel expat-devel gdb-headless zlib-devel krb5-devel
BuildRequires:  pkgconfig  make xmlto pakchois-devel libproxy-devel

%description
neon is an HTTP and WebDAV client library, with a C interface. Features:\
* High-level wrappers for common HTTP and WebDAV operations (GET, MOVE, DELETE, etc)\
Low-level interface to the HTTP request/response engine, allowing the use of arbitrary\
HTTP methods, headers, etc.\
* Authentication support including Basic and Digest support, along with GSSAPI-based\
 Negotiate on Unix, and SSPI-based Negotiate/NTLM on Win32\
* SSL/TLS support using OpenSSL or GnuTLS; exposing an abstraction layer for verifying server\
certificates, handling client certificates, and examining certificate properties.\
Smartcard-based client certificates are also supported via a PKCS#11 wrapper interface.\
* Abstract interface to parsing XML using libxml2 or expat, and wrappers for simplifying\
handling XML HTTP response bodies\
* WebDAV metadata support; wrappers for PROPFIND and PROPPATCH to simplify property\
manipulation.\


%package devel
Summary:	Development files for %{name}
Requires:	neon = %{version}-%{release}, openssl-devel, zlib-devel, expat-devel
Requires:	pkgconfig
License:	LGPL-2.0-or-later and GPL-2.0-or-later

%description devel
Libraries and header files of %{name} are all in the %{name}-devel package.

%package        help
Summary:        Help manual for %{name}

%description    help
The %{name}-help package conatins man manual etc

%prep
%autosetup -n %{name}-%{version} -p1
sed -i '/^install-docs/s/install-html//' Makefile.in

%build
export CC="%{__cc} -pthread"
%configure --with-expat --enable-shared --disable-static \
        --enable-warnings \
        --with-ssl=openssl --enable-threadsafe-ssl=posix \
        --with-libproxy
%make_build

%install
rm -rf $RPM_BUILD_ROOT
%make_install

sed -ri "/^dependency_libs/{s,-l[^ ']*,,g}" \
      $RPM_BUILD_ROOT%{_libdir}/libneon.la

%find_lang %{name}

%ldconfig_scriptlets

%files -f %{name}.lang
%doc BUGS TODO NEWS README* THANKS
%license AUTHORS src/COPYING.LIB
%{_libdir}/*.so.*

%files devel
%{_bindir}/*
%{_includedir}/*
%{_libdir}/pkgconfig/neon.pc
%{_libdir}/*.*a
%{_libdir}/*.so

%files help
%{_mandir}/man1/*
%{_mandir}/man3/*

%changelog
* Tue Mar 19 2024 liyanan <liyanan61@h-partners.comm> - 0.33.0-1
- Update to 0.33.0

* Thu May 18 2023 liyanan <thistleslyn@163.com> - 0.32.5-1
- update to 0.32.5

* Fri Dec 30 2022 Guangzhong Yao <yaoguangzhong@xfusion.com> - 0.30.2-15
- DESC: backport neon.mak: Silence deprecation/POSIX warnings

* Thu Dec 29 2022 Guangzhong Yao <yaoguangzhong@xfusion.com> - 0.30.2-14
- DESC: backport neon.mak Replace GX with EHsc

* Thu Dec 29 2022 Guangzhong Yao <yaoguangzhong@xfusion.com> - 0.30.2-13
- DESC: backport Switch to destroy_and_wait() in various places

* Sat Dec 24 2022 Wei Chen <chenwei@xfusion.com> - 0.30.2-12
- DESC: fix invalid changelog information

* Mon Aug 02 2021 chenyanpanHW <chenyanpan@huawei.com> - 0.30.2-11
- DESC: delete -Sgit from %autosetup, and delete BuildRequires git

* Wed Jun 02 2021 zhaoyao<zhaoyao32@huawei.com> - 0.30.2-10
- fixs faileds: /bin/sh: gcc: command not found.

* Wed Nov 13 2019 openEuler Buildteam <buildteam@openeuler.org> - 0.30.2-9
- Package init
